@@ -1,7 +1,6 @@
 #-----------------------------------------------------------------------------
-# Copyright (c) 2012 - 2018, Anaconda, Inc. All rights reserved.
-#
-# Powered by the Bokeh Development Team.
+# Copyright (c) 2012 - 2019, Anaconda, Inc., and Bokeh Contributors.
+# All rights reserved.
 #
 # The full license is in the file LICENSE.txt, distributed with this software.
 #-----------------------------------------------------------------------------
@@ -27,7 +26,7 @@ from mock import patch
 from bokeh.core.validation import check_integrity
 from bokeh.plotting import figure
 
-from bokeh.models import GlyphRenderer, Label, Plot, LinearAxis
+from bokeh.models import GlyphRenderer, Label, Plot, LinearAxis, CustomJS
 from bokeh.models.ranges import FactorRange, DataRange1d, Range1d
 from bokeh.models.scales import CategoricalScale, LinearScale, LogScale
 from bokeh.models.tools import PanTool
@@ -40,7 +39,7 @@ import bokeh.models.plots as bmp
 #-----------------------------------------------------------------------------
 
 _LEGEND_EMPTY_WARNING = """
-You are attemptings to set `plot.legend.location` on a plot that has zero legends added, this will have no effect.
+You are attempting to set `plot.legend.location` on a plot that has zero legends added, this will have no effect.
 
 Before legend properties can be set, you must add a Legend explicitly, or call a glyph method with the 'legend' parameter set.
 """
@@ -184,36 +183,40 @@ class TestPlotValidation(object):
         )
         assert mock_logger.error.call_args[0][0].count("Grid") == 2
 
+        # test whether adding a figure (*and* it's extra ranges)
+        # to another's references doesn't create a false positive
+        p, dep = figure(), figure()
+        dep.extra_x_ranges['foo'] = Range1d()
+        dep.grid.x_range_name="foo"
+        p.x_range.callback = CustomJS(code = "", args = {"dep": dep})
+        assert dep in p.references()
+        with mock.patch('bokeh.core.validation.check.log') as mock_logger:
+            check_integrity([p])
+        assert mock_logger.error.call_count == 0
+
 def test_plot_add_layout_raises_error_if_not_render():
     plot = figure()
     with pytest.raises(ValueError):
         plot.add_layout(Range1d())
 
 
-def test_plot_add_layout_raises_error_if_plot_already_on_annotation():
-    plot = figure()
-    with pytest.raises(ValueError):
-        plot.add_layout(Label(plot=plot))
-
-
 def test_plot_add_layout_adds_label_to_plot_renderers():
     plot = figure()
     label = Label()
     plot.add_layout(label)
-    assert label in plot.renderers
+    assert label in plot.center
 
 
 def test_plot_add_layout_adds_axis_to_renderers_and_side_renderers():
     plot = figure()
     axis = LinearAxis()
     plot.add_layout(axis, 'left')
-    assert axis in plot.renderers
     assert axis in plot.left
 
 
 def test_sizing_mode_property_is_fixed_by_default():
     plot = figure()
-    assert plot.sizing_mode == 'fixed'
+    assert plot.sizing_mode is None
 
 
 class BaseTwinAxis(object):
