@@ -1,9 +1,53 @@
+#-----------------------------------------------------------------------------
+# Copyright (c) 2012 - 2019, Anaconda, Inc., and Bokeh Contributors.
+# All rights reserved.
+#
+# The full license is in the file LICENSE.txt, distributed with this software.
+#-----------------------------------------------------------------------------
 ''' Utilities for Py2/Py3 interop.
 
 '''
 
+#-----------------------------------------------------------------------------
+# Boilerplate
+#-----------------------------------------------------------------------------
+from __future__ import absolute_import, division, print_function
+
+import logging
+log = logging.getLogger(__name__)
+
+#-----------------------------------------------------------------------------
+# Imports
+#-----------------------------------------------------------------------------
+
+# Standard library imports
 import sys
 
+# External imports
+
+# Bokeh imports
+
+#-----------------------------------------------------------------------------
+# Globals and constants
+#-----------------------------------------------------------------------------
+
+__all__ = (
+    'format_signature',
+    'get_param_info',
+    'with_metaclass',
+)
+
+#-----------------------------------------------------------------------------
+# General API
+#-----------------------------------------------------------------------------
+
+# handle collections ABC changes
+try:
+    # only works on python 3.3+ but Bokeh only support python 3.4+
+    import collections.abc as collections_abc # NOQA
+except ImportError:
+    import collections as collections_abc # NOQA
+
 def with_metaclass(meta, *bases):
     """ Add metaclasses in both Python 2 and Python 3.
 
@@ -39,6 +83,17 @@ def with_metaclass(meta, *bases):
             return meta(name, bases, d)
     return metaclass('temporary_class', None, {})
 
+#-----------------------------------------------------------------------------
+# Dev API
+#-----------------------------------------------------------------------------
+
+#-----------------------------------------------------------------------------
+# Private API
+#-----------------------------------------------------------------------------
+
+#-----------------------------------------------------------------------------
+# Code
+#-----------------------------------------------------------------------------
 
 # There is a problem with using @wraps decorator in combination with functools.partial.
 # This issue is not present in Python 3.
@@ -82,8 +137,9 @@ if sys.version_info[:2] < (3, 4):
         elif isinstance(func, partial):
             sig = getargspec(func.func)
             if 'self' in sig.args: sig.args.remove('self')
-            for name in func.keywords.keys():
-                sig.args.remove(name)
+            if func.keywords is not None:
+                for name in func.keywords.keys():
+                    sig.args.remove(name)
             for val in func.args:
                 del sig.args[0]
             return sig
